@@ -5,7 +5,7 @@ use crypto_rest_client::{fetch_l2_snapshot, fetch_open_interest};
 use serde_json::Value;
 use test_case::test_case;
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
@@ -18,7 +18,7 @@ fn test_l2_snapshot(market_type: MarketType, symbol: &str) {
     assert_eq!(result.as_array().unwrap().len(), 50);
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_open_interest(market_type: MarketType, symbol: &str) {
